Ring utility functions.
Ring utility functions.
(request->event req e)Given a request and an exception, returns a Sentry event.
Given a request and an exception, returns a Sentry event.
(wrap-report-exceptions handler
{:keys [preprocess-fn postprocess-fn error-fn]
:or {preprocess-fn identity
postprocess-fn (comp second list)
error-fn default-error}})Wraps the given handler in error reporting.
Optionally takes three functions:
:preprocess-fn, which is passed the request:postprocess-fn, which is passed the request and the Sentry event:error-fn, which is passed the request and the thrown exception and
returns an appropriate Ring responseWraps the given handler in error reporting. Optionally takes three functions: * `:preprocess-fn`, which is passed the request * `:postprocess-fn`, which is passed the request and the Sentry event * `:error-fn`, which is passed the request and the thrown exception and returns an appropriate Ring response
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |